package com.neptune.zebra;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.util.Log;

import org.apache.cordova.CallbackContext;
import org.apache.cordova.CordovaPlugin;
import org.json.JSONArray;
import org.json.JSONException;

public class ZebraRFIDPlugin extends CordovaPlugin {

    private static final String TAG = "ZebraRFIDPlugin";
    private static final String ACTION_START_SCAN = "startRFIDScan";
    private static final String ACTION_STOP_SCAN = "stopRFIDScan";
    private static final String ACTION_INITIALIZE = "initialize";

    private CallbackContext callbackContext;
    private BroadcastReceiver scanReceiver;

    @Override
    public boolean execute(String action, JSONArray args, CallbackContext callbackContext) throws JSONException {
        this.callbackContext = callbackContext;

        if (ACTION_INITIALIZE.equals(action)) {
            initializeScanReceiver();
            return true;
        } else if (ACTION_START_SCAN.equals(action)) {
            startRFIDScan();
            return true;
        } else if (ACTION_STOP_SCAN.equals(action)) {
            stopRFIDScan();
            return true;
        } else {
            return false;
        }
    }

    public void initializeScanReceiver() {
        if (scanReceiver == null) {
            scanReceiver = new BroadcastReceiver() {
                @Override
                public void onReceive(Context context, Intent intent) {
                    String scanData = intent.getStringExtra("com.symbol.datawedge.data_string");
                    if (scanData != null) {
                        Log.d(TAG, "Scanned data: " + scanData);
                        callbackContext.success(scanData); // Send data back to JavaScript
                    }
                }
            };
            IntentFilter filter = new IntentFilter();
            filter.addAction("com.symbol.datawedge.api.RESULT_ACTION");
            cordova.getActivity().registerReceiver(scanReceiver, filter);
            Log.d(TAG, "Scan receiver initialized.");
        }
    }

    public void startRFIDScan() {
        Intent intent = new Intent();
        intent.setAction("com.symbol.datawedge.api.ACTION");
        intent.putExtra("com.symbol.datawedge.api.SOFT_SCAN_TRIGGER", "START_SCANNING");
        cordova.getActivity().sendBroadcast(intent);
        Log.d(TAG, "RFID scanning started.");
        callbackContext.success("RFID scan started.");
    }

    public void stopRFIDScan() {
        Intent intent = new Intent();
        intent.setAction("com.symbol.datawedge.api.ACTION");
        intent.putExtra("com.symbol.datawedge.api.SOFT_SCAN_TRIGGER", "STOP_SCANNING");
        cordova.getActivity().sendBroadcast(intent);
        Log.d(TAG, "RFID scanning stopped.");
        callbackContext.success("RFID scan stopped.");
    }

    @Override
    public void onDestroy() {
        if (scanReceiver != null) {
            cordova.getActivity().unregisterReceiver(scanReceiver);
            scanReceiver = null;
            Log.d(TAG, "Scan receiver unregistered.");
        }
        super.onDestroy();
    }
}
